# Getting Started with the Integration API
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/getting-started-with-integration-api#overview)
  * [Key Concepts](https://help.sap.com/docs/leanix/ea/getting-started-with-integration-api#key-concepts)
  * [Preconfigured Processors](https://help.sap.com/docs/leanix/ea/getting-started-with-integration-api#preconfigured-processors)
  * [Configuring a Processor](https://help.sap.com/docs/leanix/ea/getting-started-with-integration-api#configuring-a-processor)
  * [Testing a Processor](https://help.sap.com/docs/leanix/ea/getting-started-with-integration-api#testing-a-processor)
  * [Running a Processor](https://help.sap.com/docs/leanix/ea/getting-started-with-integration-api#running-a-processor)
  * [Saving New Processor Versions](https://help.sap.com/docs/leanix/ea/getting-started-with-integration-api#saving-new-processor-versions)
  * [Getting the Data Model of Your Workspace](https://help.sap.com/docs/leanix/ea/getting-started-with-integration-api#getting-the-data-model-of-your-workspace)
  * [Managing Processors](https://help.sap.com/docs/leanix/ea/getting-started-with-integration-api#managing-processors)
